@@ -33,7 +33,7 @@ import math
 from FAdo.reex import *
 
 
-class emptyword(epsilon):
+class emptyword(CEpsilon):
     @staticmethod
     def generating(x):
         return x
@@ -45,10 +45,10 @@ class emptyword(epsilon):
     @staticmethod
     def sampler():
         """ None if empty"""
-        return [epsilon()]
+        return [CEpsilon()]
 
 
-class singleton(regexp):
+class singleton(RegExp):
     @staticmethod
     def generating(x):
         return x
@@ -62,10 +62,10 @@ class singleton(regexp):
         return [self.val]
 
 
-class union(disj):
+class union(CDisj):
     def __init__(self, *args):
         self.gen = {}
-        disj.__init__(self, *args)
+        CDisj.__init__(self, *args)
 
     def generating(self, x):
         return self.gen.setdefault(x, self.arg1.generating(x) + self.arg2.generating(x))
@@ -81,10 +81,10 @@ class union(disj):
             return self.arg2.sampler(x)
 
 
-class prod(concat):
+class prod(CConcat):
     def __init__(self, *args):
         self.gen = {}
-        concat.__init__(self, *args)
+        CConcat.__init__(self, *args)
 
     def generating(self, x):
         return self.gen.setdefault(x, self.arg1.generating(x) * self.arg2.generating(x))
@@ -99,10 +99,10 @@ class prod(concat):
         return "(%s.%s)" % (self.arg1, self.arg2)
 
 
-class seq(star):
+class seq(CStar):
     def __init__(self, *args):
         self.gen = {}
-        star.__init__(self, *args)
+        CStar.__init__(self, *args)
 
     def generating(self, x):
         return self.gen.setdefault(x, 1.0 / (1 - self.arg.generating_s(x)))
@@ -118,7 +118,7 @@ class seq(star):
             else:
                 return [self.arg.sampler(x)]
         else:
-            return epsilon()
+            return CEpsilon()
 
     def sampler(self, x):
         k = rnd_geometric(self.arg.generating(x))
