@@ -27,8 +27,9 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA."""
 
-from boltzmann import *
+from FAdo.boltzmann import *
 import copy
+from functools import reduce
 
 debug = 0
 
@@ -84,12 +85,12 @@ def genficdfas(n, k):
         nf = 1
         flags = []
         setFlags(n, k)
-        print flags
+        print(flags)
         while not islast(n, k):
             shiftFlags(n - 2)
             nf += 1
-            print flags
-        print nf
+            print(flags)
+        print(nf)
 
     def genficdfa(n, _):
         """
@@ -118,7 +119,7 @@ def genficdfas(n, k):
                 else:
                     g = singleton(j)
         if debug:
-            print g
+            print(g)
         return g
 
     nf = 1
@@ -127,16 +128,16 @@ def genficdfas(n, k):
     setFlags(n, k)
     flags = flags + [n * k]
     if debug:
-        print flags
+        print(flags)
     ic = genficdfa(n, k)
     while not islast(n, k):
         shiftFlags(n - 2)
         if debug:
-            print flags
+            print(flags)
         ic = union(ic, genficdfa(n, k))
         nf += 1
     if debug:
-        print nf
+        print(nf)
     return ic
 
 
@@ -161,17 +162,17 @@ def create_nr(k, n, t=0):
     """ t not treated"""
     nr[(k, n)] = {}
     for i in range((n - 1) * k - 1, n - 3, -1):
-        r = reduce(union, [singleton(j) for j in xrange(n)])
+        r = reduce(union, [singleton(j) for j in range(n)])
         nr[(k, n)][(n - 1, i)] = prod(singleton(n - 1),
                                       reduce(prod, [r for j in range(n * k - 1 - i)]))
 
         # (n+t)**(k*n-1-i)
     for m in range(n - 2, 0, -1):
         for j in range(m * k - 1, m - 2, -1):
-            r0 = reduce(union, [singleton(i) for i in xrange(m)])
+            r0 = reduce(union, [singleton(i) for i in range(m)])
             uu = union(nr[(k, n)][(m + 1, j + 1)], reduce(union,
                                                           [prod(reduce(prod, [r0 for l in range(i)]),
-                                                                nr[(k, n)][(m + 1, j + i + 1)]) for i in xrange(1, k)]))
+                                                                nr[(k, n)][(m + 1, j + i + 1)]) for i in range(1, k)]))
 
             nr[(k, n)][(m, j)] = prod(singleton(m), uu)
 
@@ -205,16 +206,16 @@ def test_23(m, x):
     abc = union(a, union(b, c))
     r = union(prod(union(prod(a, b), prod(b, ab)), prod(union(prod(ab, c), prod(c, abc)), prod(abc, abc))),
               prod(b, prod(c, prod(abc, prod(abc, prod(abc, abc))))))
-    print r
-    for i in xrange(m):
-        print r.sampler(x)
+    print(r)
+    for i in range(m):
+        print(r.sampler(x))
 
 
 def test_(k, n, m, x):
     a = gen_icdfas(k, n)
     #f=a.nfaPosition().toDFA().minimal()
     #print len(f.States)
-    for i in xrange(m):
-        print a.sampler(x)
+    for i in range(m):
+        print(a.sampler(x))
 
 ###Use: test_(k,n,m,x=0.5)
