@@ -38,8 +38,7 @@ class ADFArnd():
     :var int k: size of the alphabet
     :var int s: number of sources
 
-    .. note::
-       For ICDFA  s=1"""
+    **Note:** For ICDFA  s=1"""
 
     def __init__(self, n, k=2, s=1):
         assert n > 0 and n >= s
@@ -215,7 +214,7 @@ class ADFArnd():
 
         :arg t: size of T
         :arg u: size of U
-        :arg r: size of R
+        :arg r: size of r
         :type t: int
         :type u: int
         :type r: int
